<?php

namespace Drupal\file_upload_directory_change\Service;

use Drupal\Core\File\FileSystemInterface;
use Drupal\file\Entity\File;

class FileService implements FileServiceInterface {

  /**
   * Drupal file_system service.
   *
   * @var FileSystemInterface
   */
  protected $fileSystem;

  /**
   * {@inheritdoc}
   */
  public function __construct(FileSystemInterface $file_system) {
    $this->fileSystem = $file_system;
  }

  /**
   * {@inheritdoc}
   */
  public function changeFilePath($uri) {
    if (strpos($uri, 'public://') !== FALSE) {
      $uri = str_replace('public://', 'private://', $uri);
    }
    else if (strpos($uri, 'private://') !== FALSE) {
      $uri = str_replace('private://', 'public://', $uri);
    }
    return $uri;
  }

  /**
   * {@inheritdoc}
   */
  public function directoryChange($fid) {
    $file = File::load($fid);
    $uri = $file->getFileUri();
    $new_uri = $this->changeFilePath($uri);
    $directory = $this->fileSystem->dirname($new_uri);

    // Check if the new directory exists.
    if (!file_exists($directory)) {
      $this->fileSystem->mkdir($directory, NULL, TRUE);
    }

    // Move file
    file_move($file, $new_uri);
  }

}